@@ -9,6 +9,7 @@
 from otopi import util
 
 
+from . import answer_file
 from . import cli
 from . import human
 from . import machine
@@ -17,6 +18,7 @@ from . import misc
 
 @util.export
 def createPlugins(context):
+    answer_file.Plugin(context=context)
     cli.Plugin(context=context)
     human.Plugin(context=context)
     machine.Plugin(context=context)
